@@ -67,7 +67,7 @@ class CloudFront:
         for dep in meta.find_referenced_templates(self.__cm.env.parse(source)):
             self.__hash_template(dep, hsh, seen=seen)
 
-    def template(self, filename:str, status_code:int=200, headers:Optional[dict]=None, **kwargs) -> Response:
+    def template(self, filename:str, status_code:int=200, headers:Optional[dict]=None, cache_control=None, **kwargs) -> Response:
         """
         If CloudFront supplies If-None-Match header in request, then we can check against a hash
         of the template, its dependancies, and its arguments to inform CloudFront if its cache needs
@@ -76,6 +76,7 @@ class CloudFront:
         :param filename: Path to template in which to be rendered or cached
         :param status_code: Status code to return content with
         :param headers: Additional headers to return
+        :param cache_control: Controls how CloudFront manages re-evaluating the orgin. See https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html and https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control.
         :param kwargs: Keyword arguments to be passed to template in the event that it is rendered, must be pickleable
         :returns: Chalice Response object
         """
@@ -91,13 +92,15 @@ class CloudFront:
                 print(f'If-None-Match: {if_none_match} != {hsh}, Calling origin function')
                 r = self.__cm.html(self.__cm.render_template(filename, **kwargs), status_code=status_code, headers=headers)
                 r.headers['ETag'] = hsh
+                if cache_control is not None:
+                    r.headers['Cache-Control'] = cache_control
                 return r
         except Exception as e:
             print('Exception')
             traceback.print_exc()
             return self.__cm.html(self.__cm.render_template(filename, **kwargs), status_code=status_code, headers=headers)
 
-    def static(self, filename:str, status_code:int=200, headers:Optional[dict]=None) -> Response:
+    def static(self, filename:str, status_code:int=200, headers:Optional[dict]=None, cache_control=None) -> Response:
         """
         If CloudFront supplies If-Modified-Since header in request, then we can check against the
         modified date of the file to inform CloudFront if its cache needs to be updated or not.
@@ -105,6 +108,7 @@ class CloudFront:
         :param filename: Path relative from static_dir to content
         :param status_code: Status code to return content with
         :param headers: Additional headers to return
+        :param cache_control: Controls how CloudFront manages re-evaluating the orgin. See https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html and https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control.
         :returns: Chalice Response object
         """
         if_modified_since = self.__app.current_request.headers.get('If-Modified-Since')
@@ -122,14 +126,16 @@ class CloudFront:
             else:
                 print(f'If-Modified-Since: {mtime} > {if_modified_since}, Calling origin function')
                 r = self.__cm.static(filename, status_code=status_code, headers=headers)
-                r.headers['LastModified'] = mtime.strftime('%a, %d %b %Y %H:%M:%S GMT')
+                r.headers['Last-Modified'] = mtime.strftime('%a, %d %b %Y %H:%M:%S GMT')
+                if cache_control is not None:
+                    r.headers['Cache-Control'] = cache_control
                 return r
         except Exception as e:
             print('Exception')
             traceback.print_exc()
             return self.__cm.static(filename, status_code=status_code, headers=headers)
 
-    def asset(self, get_asset:Callable[[],bytes], get_etag:Callable[[],str], status_code:int=200, headers:Optional[dict]=None) -> Response:
+    def asset(self, get_asset:Callable[[],bytes], get_etag:Callable[[],str], status_code:int=200, headers:Optional[dict]=None, cache_control=None) -> Response:
         """
         Calls get_etag() to generate a tag for the asset, and if it matches the If-None-Match value,
         we return a 304. Otherwise get_asset() is called and returned.
@@ -138,6 +144,7 @@ class CloudFront:
         :param get_etag: Callable to get etag of the asset
         :param status_code: Status code to return content with
         :param headers: Additional headers to return
+        :param cache_control: Controls how CloudFront manages re-evaluating the orgin. See https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html and https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control.
         :returns: Chalice Response object
         """
         if_none_match = self.__app.current_request.headers.get('If-None-Match')
@@ -153,6 +160,8 @@ class CloudFront:
                 print(f'If-None-Match: {if_none_match} != {hsh}, Calling origin function')
                 r = self.__cm.asset(get_asset(), status_code=status_code, headers=headers)
                 r.headers['ETag'] = hsh
+                if cache_control is not None:
+                    r.headers['Cache-Control'] = cache_control
                 return r
         except Exception as e:
             print('Exception')
